using System;
using System.Text;
using System.Diagnostics;

namespace ZealSoftStudio.NTPort
{
	/// <summary>
	/// Summary description for LPTPort.
	/// </summary>
	public class LPTPort
	{
		private short portAddress = 0;
		public enum Ports {LPT1=1, LPT2=2, LPT3=3};

		public LPTPort(Ports Port)
		{
			short i = (short)Port;
			portAddress = NTPort.GetLPTPortAddress(i);
			
			if(portAddress == 0)
			{
				if (LastError)
				{
					string msg = "Error accessing the parallel port at LPT"+i+". Details: " + LastErrorMessage;
					throw new ArgumentException(msg,"Port");
				}
				else
				{
					string msg = "The parallel port at LPT"+i+" does not exist on this system.";
					throw new ArgumentException(msg,"Port");
				}
			}

			Debug.WriteLine("LPTPort msg: Found LPT"+i+" at address 0x"+Address);
		}

		public int Address
		{
			get
			{
				return (int)portAddress;
			}
		}

		public bool LastError
		{
			get
			{
				return NTPort.GetLastState(null)!=0;
			}
		}

		public string LastErrorMessage
		{
			get
			{
				StringBuilder sbError = new StringBuilder();
				NTPort.GetLastState(sbError);
				return sbError.ToString();
			}
		}

		public void Output(int DWord)
		{
			NTPort.OutportD(portAddress,DWord);
		}

		public void Output(Int16 Word)
		{
			NTPort.OutportW(portAddress,Word);
		}

		public void Output(byte Byte)
		{
			NTPort.Outport(portAddress,Byte);
		}
	}
}
